'use client';
import React from 'react';
import cx from 'clsx';
import { factory, useProps, useStyles, Box, CopyButton, Tooltip, ActionIcon, ScrollArea } from '@mantine/core';
import { CopyIcon } from './CopyIcon.mjs';
import { useHighlight } from './use-highlight.mjs';
import _classes from './CodeHighlight.module.css.mjs';
import themeClasses from './CodeHighlight.theme.module.css.mjs';

const classes = { ..._classes, root: cx(_classes.root, themeClasses.theme) };
const defaultProps = {
  copyLabel: "Copy code",
  copiedLabel: "Copied",
  language: "tsx",
  withCopyButton: true
};
const CodeHighlight = factory((_props, ref) => {
  const props = useProps("CodeHighlight", defaultProps, _props);
  const {
    classNames,
    className,
    style,
    styles,
    unstyled,
    vars,
    children,
    code,
    copiedLabel,
    copyLabel,
    language,
    withCopyButton,
    highlightOnClient,
    ...others
  } = props;
  const getStyles = useStyles({
    name: "CodeHighlight",
    props,
    classes,
    className,
    style,
    classNames,
    styles,
    unstyled
  });
  const getCodeProps = useHighlight({
    code,
    language,
    highlightOnClient
  });
  return /* @__PURE__ */ React.createElement(Box, { ...getStyles("root"), ref, ...others, dir: "ltr" }, withCopyButton && /* @__PURE__ */ React.createElement(CopyButton, { value: code.trim() }, ({ copied, copy }) => /* @__PURE__ */ React.createElement(Tooltip, { label: copied ? copiedLabel : copyLabel, fz: "sm", position: "left" }, /* @__PURE__ */ React.createElement(ActionIcon, { onClick: copy, variant: "none", ...getStyles("copy") }, /* @__PURE__ */ React.createElement(CopyIcon, { copied })))), /* @__PURE__ */ React.createElement(ScrollArea, { type: "hover", dir: "ltr", offsetScrollbars: false }, /* @__PURE__ */ React.createElement("pre", { ...getStyles("pre") }, /* @__PURE__ */ React.createElement("code", { ...getStyles("code"), ...getCodeProps() }))));
});
CodeHighlight.displayName = "@mantine/core/CodeHighlight";
CodeHighlight.classes = classes;

export { CodeHighlight };
//# sourceMappingURL=CodeHighlight.mjs.map
